..
    Copyright (C) 2022 CERN.

    Invenio-RDM-Migrator is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.


Usage
=====

.. automodule:: invenio_rdm_migrator
